@@ -197,7 +197,7 @@ class ControlPanel(Gtk.Window):
             row = 0
             column = 2
 
-        options = self._options.keys()
+        options = list(self._options.keys())
         options.sort()
 
         for option in options:
@@ -205,7 +205,7 @@ class ControlPanel(Gtk.Window):
                                        title=self._options[option]['title'],
                                        xo_color=self._options[option]['color'],
                                        pixel_size=style.GRID_CELL_SIZE)
-            sectionicon.connect('button_press_event',
+            sectionicon.connect('button-press-event',
                                 self.__select_option_cb, option)
             sectionicon.show()
 
@@ -497,13 +497,15 @@ class ModelWrapper(object):
         return getattr(self._module, name)
 
     def undo(self):
-        for key in self._options.keys():
+        for key in list(self._options.keys()):
             method = getattr(self._module, 'set_' + key, None)
             if method and self._options[key] is not None:
                 try:
                     method(self._options[key])
                 except Exception as detail:
                     _logger.debug('Error undo option: %s', detail)
+
+
 if hasattr(ControlPanel, 'set_css_name'):
     ControlPanel.set_css_name('controlpanel')
 
